pub fn json_host_invocation_envelope(
outcome: Result<JsonInvocationOutcome, RuntimeFailure>,
) -> ValueExpand description
Encodes a host import Request result into the stable guest envelope.
pub fn json_host_invocation_envelope(
outcome: Result<JsonInvocationOutcome, RuntimeFailure>,
) -> ValueEncodes a host import Request result into the stable guest envelope.