pub struct InstanceResources { /* private fields */ }Expand description
Immutable, content-addressed files owned by one Plugin Instance Generation.
Implementations
Sourceimpl InstanceResources
impl InstanceResources
Sourcepub fn from_files(
files: impl IntoIterator<Item = (String, Vec<u8>)>,
) -> Result<Self, RuntimeFailure>
pub fn from_files( files: impl IntoIterator<Item = (String, Vec<u8>)>, ) -> Result<Self, RuntimeFailure>
Builds one deterministic snapshot from normalized relative paths and owned bytes.
Sourcepub fn digest(&self) -> &str
pub fn digest(&self) -> &str
Returns the deterministic identity of every path and byte in this snapshot.
Sourcepub fn file_count(&self) -> usize
pub fn file_count(&self) -> usize
Returns the number of snapshotted files.
Sourcepub const fn total_size(&self) -> u64
pub const fn total_size(&self) -> u64
Returns the aggregate byte size.
Sourcepub fn paths(&self) -> impl Iterator<Item = &str>
pub fn paths(&self) -> impl Iterator<Item = &str>
Lists normalized paths in deterministic order.